==> zio-aws-ec2_2.12-5.17.145.1-sources.jar: zio/aws/ec2/model/ReplaceRootVolumeTask.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ReplaceRootVolumeTaskId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ReplaceRootVolumeTask(
    replaceRootVolumeTaskId: Option[ReplaceRootVolumeTaskId] = None,
    instanceId: Option[String] = None,
    taskState: Option[zio.aws.ec2.model.ReplaceRootVolumeTaskState] = None,
    startTime: Option[String] = None,
    completeTime: Option[String] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask = {
    import ReplaceRootVolumeTask.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
      .builder()
      .optionallyWith(
        replaceRootVolumeTaskId.map(value =>
          ReplaceRootVolumeTaskId.unwrap(value): java.lang.String
        )
      )(_.replaceRootVolumeTaskId)
      .optionallyWith(instanceId.map(value => value: java.lang.String))(
        _.instanceId
      )
      .optionallyWith(taskState.map(value => value.unwrap))(_.taskState)
      .optionallyWith(startTime.map(value => value: java.lang.String))(
        _.startTime
      )
      .optionallyWith(completeTime.map(value => value: java.lang.String))(
        _.completeTime
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ReplaceRootVolumeTask.ReadOnly =
    zio.aws.ec2.model.ReplaceRootVolumeTask.wrap(buildAwsValue())
}
object ReplaceRootVolumeTask {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ReplaceRootVolumeTask =
      zio.aws.ec2.model.ReplaceRootVolumeTask(
        replaceRootVolumeTaskId.map(value => value),
        instanceId.map(value => value),
        taskState.map(value => value),
        startTime.map(value => value),
        completeTime.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def replaceRootVolumeTaskId: Option[ReplaceRootVolumeTaskId]
    def instanceId: Option[String]
    def taskState: Option[zio.aws.ec2.model.ReplaceRootVolumeTaskState]
    def startTime: Option[String]
    def completeTime: Option[String]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getReplaceRootVolumeTaskId
        : ZIO[Any, AwsError, ReplaceRootVolumeTaskId] = AwsError
      .unwrapOptionField("replaceRootVolumeTaskId", replaceRootVolumeTaskId)
    def getInstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceId", instanceId)
    def getTaskState
        : ZIO[Any, AwsError, zio.aws.ec2.model.ReplaceRootVolumeTaskState] =
      AwsError.unwrapOptionField("taskState", taskState)
    def getStartTime: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getCompleteTime: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("completeTime", completeTime)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
  ) extends zio.aws.ec2.model.ReplaceRootVolumeTask.ReadOnly {
    override val replaceRootVolumeTaskId: Option[ReplaceRootVolumeTaskId] =
      scala
        .Option(impl.replaceRootVolumeTaskId())
        .map(value =>
          zio.aws.ec2.model.primitives.ReplaceRootVolumeTaskId(value)
        )
    override val instanceId: Option[String] =
      scala.Option(impl.instanceId()).map(value => value: String)
    override val taskState
        : Option[zio.aws.ec2.model.ReplaceRootVolumeTaskState] = scala
      .Option(impl.taskState())
      .map(value => zio.aws.ec2.model.ReplaceRootVolumeTaskState.wrap(value))
    override val startTime: Option[String] =
      scala.Option(impl.startTime()).map(value => value: String)
    override val completeTime: Option[String] =
      scala.Option(impl.completeTime()).map(value => value: String)
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
  ): zio.aws.ec2.model.ReplaceRootVolumeTask.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.17.269.1-sources.jar: zio/aws/ec2/model/ReplaceRootVolumeTask.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ReplaceRootVolumeTaskId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ReplaceRootVolumeTask(
    replaceRootVolumeTaskId: Optional[ReplaceRootVolumeTaskId] =
      Optional.Absent,
    instanceId: Optional[String] = Optional.Absent,
    taskState: Optional[zio.aws.ec2.model.ReplaceRootVolumeTaskState] =
      Optional.Absent,
    startTime: Optional[String] = Optional.Absent,
    completeTime: Optional[String] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.ec2.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask = {
    import ReplaceRootVolumeTask.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
      .builder()
      .optionallyWith(
        replaceRootVolumeTaskId.map(value =>
          ReplaceRootVolumeTaskId.unwrap(value): java.lang.String
        )
      )(_.replaceRootVolumeTaskId)
      .optionallyWith(instanceId.map(value => value: java.lang.String))(
        _.instanceId
      )
      .optionallyWith(taskState.map(value => value.unwrap))(_.taskState)
      .optionallyWith(startTime.map(value => value: java.lang.String))(
        _.startTime
      )
      .optionallyWith(completeTime.map(value => value: java.lang.String))(
        _.completeTime
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ReplaceRootVolumeTask.ReadOnly =
    zio.aws.ec2.model.ReplaceRootVolumeTask.wrap(buildAwsValue())
}
object ReplaceRootVolumeTask {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ReplaceRootVolumeTask =
      zio.aws.ec2.model.ReplaceRootVolumeTask(
        replaceRootVolumeTaskId.map(value => value),
        instanceId.map(value => value),
        taskState.map(value => value),
        startTime.map(value => value),
        completeTime.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def replaceRootVolumeTaskId: Optional[ReplaceRootVolumeTaskId]
    def instanceId: Optional[String]
    def taskState: Optional[zio.aws.ec2.model.ReplaceRootVolumeTaskState]
    def startTime: Optional[String]
    def completeTime: Optional[String]
    def tags: Optional[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getReplaceRootVolumeTaskId
        : ZIO[Any, AwsError, ReplaceRootVolumeTaskId] = AwsError
      .unwrapOptionField("replaceRootVolumeTaskId", replaceRootVolumeTaskId)
    def getInstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceId", instanceId)
    def getTaskState
        : ZIO[Any, AwsError, zio.aws.ec2.model.ReplaceRootVolumeTaskState] =
      AwsError.unwrapOptionField("taskState", taskState)
    def getStartTime: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getCompleteTime: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("completeTime", completeTime)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
  ) extends zio.aws.ec2.model.ReplaceRootVolumeTask.ReadOnly {
    override val replaceRootVolumeTaskId: Optional[ReplaceRootVolumeTaskId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.replaceRootVolumeTaskId())
        .map(value =>
          zio.aws.ec2.model.primitives.ReplaceRootVolumeTaskId(value)
        )
    override val instanceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.instanceId())
      .map(value => value: String)
    override val taskState
        : Optional[zio.aws.ec2.model.ReplaceRootVolumeTaskState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.taskState())
        .map(value => zio.aws.ec2.model.ReplaceRootVolumeTaskState.wrap(value))
    override val startTime: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.startTime())
      .map(value => value: String)
    override val completeTime: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.completeTime())
      .map(value => value: String)
    override val tags: Optional[List[zio.aws.ec2.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ReplaceRootVolumeTask
  ): zio.aws.ec2.model.ReplaceRootVolumeTask.ReadOnly = new Wrapper(impl)
}
